# velocileptors

This directory contains supporting modules for the velocileptors code:

(1) qfuncfft.py: a class to compute PT kernels using 1d-ffts

(2) spherical_bessel_transform.py and spherical_bessel_transform_fftw.py: two fftlog routines, one that uses numpy FFTs and the other fftw.

(3) loginterp.py: a function for performing log-extrapolated interpolating functions.
